@@ -9,13 +9,11 @@
 #define TOPIC_TEMPLATE_H_
 
 #include "Sample.h"
+#include "BaseTemplate.h"
 
-#include <Wt/WTemplate.h>
-
-class TopicTemplate : public Wt::WTemplate
-{
+class TopicTemplate : public BaseTemplate {
 public:
-  TopicTemplate(const char *trKey);
+  explicit TopicTemplate(const char *trKey);
 
   virtual void resolveString(const std::string& varName,
                              const std::vector<Wt::WString>& args,
